cpw.nader.asynclogging-3: 8b6ed524: Cleaned up the last of the make docs iss...

morshed.nader at gmail.com morshed.nader at gmail.com
Mon Mar 21 00:13:04 EDT 2011


----------------------------------------------------------------------
Revision: 8b6ed524bb9655831ee507f15953bbd39a0d2b96
Parent:   766a12c88da00b95022b367bad070255f3c17f9d
Author:   morshed.nader at gmail.com
Date:     03/21/11 00:06:27
Branch:   im.pidgin.cpw.nader.asynclogging-3
URL: http://d.pidgin.im/viewmtn/revision/info/8b6ed524bb9655831ee507f15953bbd39a0d2b96

Changelog: 

Cleaned up the last of the make docs issues relating to log.h

Changes against parent 766a12c88da00b95022b367bad070255f3c17f9d

  patched  libpurple/log.h

-------------- next part --------------
============================================================
--- libpurple/log.h	c5c1f1de7d69490450b52aee0b91c1a35cea4fcb
+++ libpurple/log.h	02694a4598106ad9644bf47873506fe874cb5f57
@@ -592,16 +592,17 @@ GList *purple_log_get_logs_finish(Purple
  * Gets a list of all available logs for all available added loggers.
  * See purple_log_get_logs() for more details.
  *
  * @param type         The type of the log
  * @param name         The name of the log
  * @param account      The account
+ * @param cancellable  (allow-none): GCancellable object
  * @param error        (out) (allow-none): a GError location to store the error
  *
  * @return             pointer to log list or %NULL on error
  *
  * @since 3.0.0
  */
-GList *purple_logs_get_logs(PurpleLogChatType type, const gchar *name,
+GList *purple_logs_get_logs(PurpleLogChatType chat_type, const gchar *name,
 	PurpleAccount *account, GCancellable *cancellable, GError **error);
 
 /**
@@ -772,6 +773,7 @@ void purple_log_get_total_size_async(Pur
 /**
  * Finishes asynchronously getting the total size of a conversation
  *
+ * @param log          A dummy log of the type of logger to use
  * @param res          A GAsyncResult
  * @param error        (out) (allow-none): a GError location to store the error
  *
@@ -991,6 +993,8 @@ gboolean purple_log_is_removable(PurpleL
  * Removes a log
  *
  * @param log          The log
+ * @param cancellable  (allow-none): GCancellable object
+ * @param error        (out) (allow-none): a GError location to store the error
  *
  * @return             %TRUE if the log was removed, %FALSE otherwise
  */
@@ -998,7 +1002,8 @@ gboolean purple_log_remove(PurpleLog *lo
 	GError **error);
 
 /**
- * Asychronously removes a log
+ * Asychronously removes a log.
+ * See purple_log_remove() for more details.
  *
  * @param log          The log
  * @param io_priority  The io priority of the request
@@ -1013,7 +1018,7 @@ void purple_log_remove_async(PurpleLog *
 	GCancellable *cancellable, GAsyncReadyCallback cb, gpointer userdata);
 
 /**
- * Finishes asynchronously deleting a log
+ * Finishes asynchronously removing a log
  *
  * @param log          The log that was to be removed
  * @param res          A GAsyncResult
@@ -592,16 +592,17 @@ GList *purple_log_get_logs_finish(Purple
  * See purple_log_get_logs() for more details.
  *
- * @param type         The type of the log
+ * @param chat_type    The type of the log
  * @param name         The name of the log
  * @param account      The account


More information about the Commits mailing list